@@ -28,8 +28,9 @@
 #'   residuals.
 #' @param noise.factor amount of noise.
 #' @param force if TRUE, the algorithm tries to find a solution in any case,
-#'   possible by using different robust methods automatically.
-#' @param robMethod regression method when the response is continuous.
+#'   possible by using different robust methods automatically. 
+#' @param robMethod regression method when the response is continuous. Default is
+#'   MM-regression with `lmrob`.
 #' @param force.mixed if TRUE, the algorithm tries to find a solution in any
 #'   case, possible by using different robust methods automatically.
 #' @param addMixedFactors if TRUE add additional factor variable for each
@@ -52,7 +53,6 @@
 #'   status
 #' @return the imputed data set.
 #' @author Matthias Templ, Alexander Kowarik
-#' @seealso [mi::mi()]
 #' @references M. Templ, A. Kowarik, P. Filzmoser (2011) Iterative stepwise
 #' regression imputation using standard and robust methods.  *Journal of
 #' Computational Statistics and Data Analysis*, Vol. 55, pp. 2793-2806.
@@ -97,7 +97,7 @@
 #' @export
 irmi <- function(x, eps = 5, maxit = 100, mixed = NULL, mixed.constant = NULL,
     count = NULL, step = FALSE, robust = FALSE, takeAll = TRUE, noise = TRUE,
-    noise.factor = 1, force = FALSE, robMethod = "MM", force.mixed = TRUE,
+    noise.factor = 1, force = FALSE, robMethod = "lmrob", force.mixed = TRUE,
     mi = 1, addMixedFactors = FALSE, trace = FALSE, init.method = "kNN",
     modelFormulas = NULL, multinom.method = "multinom", imp_var = TRUE,
     imp_suffix = "imp") {
@@ -527,9 +527,9 @@ irmi <- function(x, eps = 5, maxit = 100, mixed = NULL, mixed.constant = NULL,
         }
         colnames(data_for_reg)[1] <- "y"
         new.dat <- data.frame(cbind(rep(1, length(wy)), x_part[wy,, drop = FALSE]))
-        if (class(data_for_reg$y) == "numeric")
+        if (inherits(data_for_reg$y, "numeric"))
           meth <- "numeric"
-        else if (class(data_for_reg$y) == "factor" & length(levels(data_for_reg$y)) == 2)
+        else if (inherits(data_for_reg$y, "factor") & length(levels(data_for_reg$y)) == 2)
           meth <- "bin"
         else
           meth <- "factor"
@@ -591,6 +591,8 @@ irmi <- function(x, eps = 5, maxit = 100, mixed = NULL, mixed.constant = NULL,
 ### utility functions
 anyNA <- function(X) any(is.na(X))
 Unit <- function(A) UseMethod("Unit")
+#' @export
+#' @method Unit list
 Unit.list <- function(A) {
   # Units a list of vectors into one vector
   a <- vector()
@@ -600,6 +602,8 @@ Unit.list <- function(A) {
   levels(as.factor(a))
 }
 Inter <- function(A) UseMethod("Inter")
+#' @export
+#' @method Inter list
 Inter.list <- function(A) {
   # common entries from a list of vectors
   a <- Unit(A)
@@ -612,12 +616,12 @@ Inter.list <- function(A) {
   levels(as.factor(a[TF]))
 }
 
-
-
-#' Initialization of missing values
+#' @title Initialization of missing values
+#' @name initialise
 #'
-#' Rough estimation of missing values in a vector according to its type.
+#' @description Rough estimation of missing values in a vector according to its type.
 #'
+#' @details
 #' Missing values are imputed with the mean for vectors of class
 #' `"numeric"`, with the median for vectors of class `"integer"`, and
 #' with the mode for vectors of class `"factor"`.  Hence, `x` should
@@ -697,7 +701,7 @@ useLM <- function(x_reg, ndata, wy, mixed_tf, mixed_constant, factors, step,
     x_reg1$y[x_reg$y == mixed_constant] <- 0
     x_reg1$y[x_reg$y != mixed_constant] <- 1
     form <- form[form %in% names(x_reg1)]
-    if (class(form) != "formula")
+    if (!inherits(form, "formula"))
       form <- as.formula(paste("y ~", paste(form, collapse = "+")))
     else
       form <- y ~ .
@@ -742,7 +746,7 @@ useLM <- function(x_reg, ndata, wy, mixed_tf, mixed_constant, factors, step,
     imp <- rep(1, nrow(ndata))
   }
   ##Two-Step
-  if (class(form) != "formula") {
+  if (!inherits(form, "formula")) {
     form <- form[form %in% names(x_reg)]
     if (length(form) > 0)
       form <- as.formula(paste("y ~", paste(form, collapse = "+")))
