@@ -6,8 +6,10 @@ lengthL <- function(x){
   }
 }
 
-dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mixedX,levOrdersX,
-                        don_index,imp_index,weightsx,k,mixed.constant,provideMins=TRUE){
+dist_single <- function(don_dist_var,imp_dist_var,numericalX,
+                        factorsX,ordersX,mixedX,levOrdersX,
+                        don_index,imp_index,weightsx,k,mixed.constant,
+                        provideMins=TRUE,methodStand){
   #gd <- distance(don_dist_var,imp_dist_var,weights=weightsx)
   if(is.null(mixed.constant))
     mixed.constant <- rep(0,length(mixedX))
@@ -15,13 +17,13 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
   if(provideMins){
     gd <- gowerD(don_dist_var,imp_dist_var,weights=weightsx,numericalX,
                  factorsX,ordersX,mixedX,levOrdersX,mixed.constant=mixed.constant,returnIndex=TRUE,
-                 nMin=as.integer(k),returnMin=TRUE);
+                 nMin=as.integer(k),returnMin=TRUE,methodStand = methodStand)
     colnames(gd$mins) <- imp_index
     erg2 <- as.matrix(gd$mins)
   }else{
     gd <- gowerD(don_dist_var,imp_dist_var,weights=weightsx,numericalX,
                  factorsX,ordersX,mixedX,levOrdersX,mixed.constant=mixed.constant,returnIndex=TRUE,
-                 nMin=as.integer(k));
+                 nMin=as.integer(k), methodStand=methodStand)
     erg2 <- NA
   }
   colnames(gd$ind) <- imp_index
@@ -40,7 +42,6 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
 ## (k)NN-Imputation
 #data - data.frame of the data with missing
 #variable - vector of variablesnames to be imputed
-#metric - method for distance computation of in function daisy(cluster), otherwise automatical selection
 #k - number of neighbours used
 #dist_var - list/vector of the variablenames used for distance computation
 #weights - list/vector of the weights for the different dist variables
@@ -62,7 +63,6 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
 #' @aliases kNN
 #' @param data data.frame or matrix
 #' @param variable variables where missing values should be imputed
-#' @param metric metric to be used for calculating the distances between
 #' @param k number of Nearest Neighbours used
 #' @param dist_var names or variables to be used for distance calculation
 #' @param weights weights for the variables for distance calculation.
@@ -75,7 +75,8 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
 #' @param makeNA list of length equal to the number of variables, with values, that should be converted to NA for each variable
 #' @param NAcond list of length equal to the number of variables, with a condition for imputing a NA
 #' @param impNA TRUE/FALSE whether NA should be imputed
-#' @param donorcond condition for the donors e.g. list(">5"), must be NULL or a list of same length as variable
+#' @param donorcond list of length equal to the number of variables, with a donorcond condition as character string.
+#' e.g. a list element can be ">5" or c(">5","<10). If the list element for a variable is NULL no condition will be applied for this variable.
 #' @param trace TRUE/FALSE if additional information about the imputation
 #' process should be printed
 #' @param imp_var TRUE/FALSE if a TRUE/FALSE variables for each imputed
@@ -94,6 +95,9 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
 #' Be aware that this results in a dependency on the ordering of the variables.
 #' @param weightDist TRUE/FALSE if the distances of the k nearest neighbours should be used as weights in the
 #' aggregation step
+#' @param methodStand either "range" or "iqr" to be used in the standardization of numeric vaiables in the gower distance
+#' @param ordFun function for aggregating the k Nearest Neighbours in the case
+#' of a ordered factor variable
 #' @return the imputed data set.
 #' @author Alexander Kowarik, Statistik Austria
 #' @references A. Kowarik, M. Templ (2016) Imputation with
@@ -109,12 +113,19 @@ dist_single <- function(don_dist_var,imp_dist_var,numericalX,factorsX,ordersX,mi
 #' kNN(sleep, numFun = weightedMean, weightDist=TRUE)
 #'
 #' @export
-kNN <- function(data, variable=colnames(data), metric=NULL, k=5, dist_var=colnames(data),weights=NULL,
+kNN <- function(data, variable=colnames(data), k=5, dist_var=colnames(data),weights=NULL,
                 numFun = median, catFun=maxCat,
                 makeNA=NULL,NAcond=NULL, impNA=TRUE, donorcond=NULL,mixed=vector(),mixed.constant=NULL,trace=FALSE,
-                imp_var=TRUE,imp_suffix="imp", addRF=FALSE, onlyRF=FALSE,addRandom=FALSE,useImputedDist=TRUE,weightDist=FALSE) {
+                imp_var=TRUE,imp_suffix="imp", addRF=FALSE, onlyRF=FALSE,
+                addRandom=FALSE,useImputedDist=TRUE,weightDist=FALSE,
+                methodStand = "range",
+                ordFun = medianSamp) {
   check_data(data)
   data_df <- !is.data.table(data)
+  # check for colnames before forcing variable
+  if (is.null(colnames(data))) { 
+    colnames(data) <- colnames(data, do.NULL = FALSE)
+  }
   force(variable)
   force(dist_var)
   if (data_df) {
@@ -211,12 +222,7 @@ kNN <- function(data, variable=colnames(data), metric=NULL, k=5, dist_var=colnam
 
   ###Make an index for selecting donors
   INDEX <- 1:ndat
-  ##START DISTANCE IMPUTATION
-  ## if(is.null(metric))
-  ##   metric <- c("euclidean", "manhattan", "gower")
-  ## else if(!metric%in%c("euclidean", "manhattan", "gower"))
-  ##   stop("metric is unknown")
-
+  
   # add features using random forest (ranger)
   if(addRF){
 
@@ -363,11 +369,13 @@ kNN <- function(data, variable=colnames(data), metric=NULL, k=5, dist_var=colnam
         dist_varx <- dist_var[dist_var!=variable[j]]
         weightsx <- weights[dist_var%in%dist_varx]
       }
-      if(!is.null(donorcond)){
-        cmd <- paste0("TF <- data[,sapply(.SD,function(x)!is.na(x)&x",donorcond[[j]],"),.SDcols=variable[j]][,1]")
+      if(!is.null(donorcond) && !is.null(donorcond[[j]])){
+        cmd <- paste0("TF <- data[,sapply(.SD,function(x)!is.na(x)&",
+                      paste("x", donorcond[[j]], collapse="&"),
+                      "),.SDcols=variable[j]][,1]")
         eval(parse(text=cmd))
         don_dist_var <- data[TF,dist_varx,with=FALSE]
-        don_index <- INDEX[TF]
+        don_index <- INDEX[TF]  
       }else{
         TF <- data[,sapply(.SD,function(x)!is.na(x)),.SDcols=variable[j]][,1]
         don_dist_var <- data[TF,dist_varx,with=FALSE]
@@ -394,7 +402,8 @@ kNN <- function(data, variable=colnames(data), metric=NULL, k=5, dist_var=colnam
       mixedX <-mixed[mixed%in%dist_varx]
       #dist_single provide the rows of the k nearest neighbours and the corresponding distances
       mindi <- dist_single(as.data.frame(don_dist_var),as.data.frame(imp_dist_var),numericalX,factorsX,ordersX,mixedX,levOrdersX,
-          don_index,imp_index,weightsx,k,mixed.constant,provideMins=weightDist)
+          don_index,imp_index,weightsx,k,mixed.constant,provideMins=weightDist,
+          methodStand = methodStand)
       getI <- function(x)data[x,variable[j],with=FALSE]
       if(trace)
         message(sum(indexNA2s[,variable[j]]),"items of","variable:",variable[j]," imputed\n")
@@ -413,18 +422,23 @@ kNN <- function(data, variable=colnames(data), metric=NULL, k=5, dist_var=colnam
           warning("There is no explicit 'weights' argument in your categorical aggregation function.")
         }
         #1-dist because dist is between 0 and 1
-        mindi[[2]] <- 1-mindi[[2]]
+        mindi[[2]] <- apply(1-mindi[[2]], 2, function(x)
+          pmax(min(x[x>0])/10,x))
         ### warning if there is no argument named weights
-        if(variable[j]%in%factors)
+        if(variable[j]%in%factors){
           data[indexNA2s[,variable[j]],variable[j]] <- sapply(1:ncol(kNNs),function(x)do.call("catFun",list(unlist(kNNs[,x,with=FALSE]),mindi[[2]][,x])))
-        else if(is.integer(data[,variable[j]])){
+        }else if(variable[j]%in%orders){
+          data[indexNA2s[,variable[j]],variable[j]] <- sapply(1:ncol(kNNs),function(x)do.call("ordFun",list(unlist(kNNs[,x,with=FALSE]),mindi[[2]][,x])))
+        }else if(is.integer(data[,variable[j]])){
           data[indexNA2s[,variable[j]],variable[j]] <- round(sapply(1:ncol(kNNs),function(x)do.call("numFun",list(unlist(kNNs[,x,with=FALSE]),mindi[[2]][,x]))))
         }else
           data[indexNA2s[,variable[j]],variable[j]] <- sapply(1:ncol(kNNs),function(x)do.call("numFun",list(unlist(kNNs[,x,with=FALSE]),mindi[[2]][,x])))
       }else{
-        if(variable[j]%in%factors)
+        if(variable[j]%in%factors){
           data[indexNA2s[,variable[j]],variable[j]] <- apply(kNNs,2,catFun)
-        else if(is.integer(data[,variable[j]])){
+        }else if(variable[j]%in%orders){
+          data[indexNA2s[,variable[j]],variable[j]] <- sapply(kNNs, ordFun)
+        }else if(is.integer(data[,variable[j]])){
           data[indexNA2s[,variable[j]],variable[j]] <- round(apply(kNNs,2,numFun))
         }else
           data[indexNA2s[,variable[j]],variable[j]] <- apply(kNNs,2,numFun)
