@@ -1,68 +1,3 @@
-#' Fast matching/imputation based on categorical variable
-#' 
-#' Suitable donors are searched based on matching of the categorical variables.
-#' The variables are dropped in reversed order, so that the last element of
-#' 'match_var' is dropped first and the first element of the vector is dropped last.
-#' 
-#' The method works by sampling values from the suitable donors.
-#' 
-#' @aliases matchImpute
-#' @param data data.frame, data.table, survey object or matrix
-#' @param variable variables to be imputed
-#' @param match_var variables used for matching
-#' @param imp_var TRUE/FALSE if a TRUE/FALSE variables for each imputed
-#' variable should be created show the imputation status
-#' @param imp_suffix suffix for the TRUE/FALSE variables showing the imputation
-#' status
-#' @return the imputed data set.
-#' @author Johannes Gussenbauer, Alexander Kowarik
-#' @seealso \code{\link[VIM]{hotdeck}}
-#' @keywords manip
-#' @examples
-#' 
-#' data(sleep,package="VIM")
-#' imp_data <- matchImpute(sleep,variable=c("NonD","Dream","Sleep","Span","Gest"),
-#'   match_var=c("Exp","Danger"))
-#' 
-#' data(testdata,package="VIM")
-#' imp_testdata1 <- matchImpute(testdata$wna,match_var=c("c1","c2","b1","b2"))
-#'
-#' dt <- data.table(testdata$wna)
-#' imp_testdata2 <- matchImpute(dt,match_var=c("c1","c2","b1","b2"))
-
-# working function
-#' @export matchImpute
-matchImpute <- function(data,variable=colnames(data)[!colnames(data)%in%match_var],match_var, imp_var=TRUE,
-    imp_suffix="imp") {
-  UseMethod("matchImpute", data)
-}
-
-#' @rdname matchImpute
-#' @export
-
-matchImpute.data.frame <- function(data,variable=colnames(data)[!colnames(data)%in%match_var],match_var, imp_var=TRUE,
-    imp_suffix="imp") {
-  as.data.frame(matchImpute.default(data.table(data), variable, match_var, imp_var, imp_suffix))
-}
-
-#' @rdname matchImpute
-#' @export
-
-matchImpute.data.table <- function(data,variable=colnames(data)[!colnames(data)%in%match_var],match_var, imp_var=TRUE,
-    imp_suffix="imp") {
-  matchImpute.default(copy(data), variable, match_var, imp_var, imp_suffix)
-}
-
-#' @rdname matchImpute
-#' @export
-
-matchImpute.survey.design <- function(data,variable=colnames(data$variables)[!colnames(data$variables)%in%match_var],match_var, imp_var=TRUE,
-    imp_suffix="imp") {
-  data$variables <- matchImpute.default(data.table(data$variables), variable,
-      match_var, imp_var, imp_suffix)
-  data$call <- sys.call(-1)
-  data
-}
 primitive.impute <- function(x){
   x.na <- is.na(x)
   if(all(!x.na)|all(x.na)){
@@ -80,16 +15,58 @@ primitive.impute <- function(x){
   }
   return(x)
 }
-# main function
-# imp_var can only be a single collumn (yet)
 
-#' @rdname matchImpute
+#' Fast matching/imputation based on categorical variable
+#' 
+#' Suitable donors are searched based on matching of the categorical variables.
+#' The variables are dropped in reversed order, so that the last element of
+#' 'match_var' is dropped first and the first element of the vector is dropped last.
+#' 
+#' The method works by sampling values from the suitable donors.
+#' 
+#' @aliases matchImpute
+#' @param data data.frame, data.table or matrix
+#' @param variable variables to be imputed
+#' @param match_var variables used for matching
+#' @param imp_var TRUE/FALSE if a TRUE/FALSE variables for each imputed
+#' variable should be created show the imputation status
+#' @param imp_suffix suffix for the TRUE/FALSE variables showing the imputation
+#' status
+#' @return the imputed data set.
+#' @author Johannes Gussenbauer, Alexander Kowarik
+#' @seealso [VIM::hotdeck()]
+#' @keywords manip
+#' @family imputation methods
+#' @examples
+#' 
+#' data(sleep,package="VIM")
+#' imp_data <- matchImpute(sleep,variable=c("NonD","Dream","Sleep","Span","Gest"),
+#'   match_var=c("Exp","Danger"))
+#' 
+#' data(testdata,package="VIM")
+#' imp_testdata1 <- matchImpute(testdata$wna,match_var=c("c1","c2","b1","b2"))
+#'
+#' dt <- data.table::data.table(testdata$wna)
+#' imp_testdata2 <- matchImpute(dt,match_var=c("c1","c2","b1","b2"))
+
+# working function
 #' @export
-
-matchImpute.default <- function(data,variable=colnames(data)[!colnames(data)%in%match_var],match_var, imp_var=TRUE,
+matchImpute <- function(data,variable=colnames(data)[!colnames(data)%in%match_var],match_var, imp_var=TRUE,
     imp_suffix="imp"){
+  check_data(data)
+  is_df <- !is.data.table(data)
+  if (is_df)
+    data <- as.data.table(data)
+  else
+    data <- data.table::copy(data)
+  tfna <- data[,sapply(lapply(.SD,is.na),all),.SDcols=variable]
+  if(any(tfna)){
+    stop(paste0(variable[tfna],collapse=", ")," ", ifelse(sum(tfna)>1,"are","is")," completely missing")
+    
+  }
   na_present <- data[,sum(sapply(lapply(.SD,is.na),sum)),.SDcols=variable]
   
+  
   if(imp_var){
     data[,paste(variable,imp_suffix,sep="_"):=lapply(.SD,is.na),.SDcols=variable]
   }
@@ -113,6 +90,8 @@ matchImpute.default <- function(data,variable=colnames(data)[!colnames(data)%in%
     count_missings <- rbind(count_missings,c(j,na_present))
   }
   attr(data,"count_missings") <- count_missings
+  if (is_df)
+    data <- as.data.frame(data)
   return(data)
   
-}
\ No newline at end of file
+}
