@@ -10,7 +10,8 @@
 #'
 #'
 #' [lm()] is used for family "normal" and [glm()] for all other families.
-#' (robust=TRUE: [lmrob()], [glmrob()])
+#' If \code{robust = TRUE}, \link[robustbase:lmrob]{lmrob()} is used for family "normal" 
+#' and \link[robustbase:glmrob]{glmrob()} for all other families.
 #'
 #' @param formula model formula to impute one variable
 #' @param data A data.frame containing the data
@@ -57,10 +58,10 @@ regressionImp <- function(formula, data, family = "AUTO", robust = FALSE, imp_va
     if (!any(is.na(lhs_vector))) {
       cat(paste0("No missings in ", lhsV, ".\n"))
     } else {
-      if (!inherits(family, "function")) {
+      if (!inherits(family, "function") & !inherits(family, "family")){
         if (family == "AUTO") {
           TFna <- TFna2 & !is.na(lhs_vector)
-          if (inherits(lhs_vector, "numeric")) {
+          if (is.numeric(lhs_vector)) {
             nLev <- 0
             if (robust) {
               fn <- lmrob
