@@ -19,6 +19,12 @@
 
 # ---------------------------------------
 
+check_data <- function(data) {
+  if (inherits(data, "survey.design"))
+    stop("support for survey.design objects was removed in VIM",
+         " 6.0.0. Use data.frame or data.table instead")
+}
+
 ## utilities for data
 getEscapeChars <- function() {
   c("", "_", "__", "-", " ", "/", "\\", ",")
@@ -94,8 +100,8 @@ isImp <- function(x, pos, delimiter, imp_var, selection = c("none","any","all"))
 #' 
 #' @aliases countInf countNA
 #' @param x a vector.
-#' @return  \code{countInf} returns the number of infinite values in \code{x}.
-#' \code{countNA} returns the number of missing values in \code{x}.
+#' @return  `countInf` returns the number of infinite values in `x`.
+#' `countNA` returns the number of missing values in `x`.
 #' @author Andreas Alfons
 #' @keywords utilities
 #' @examples
@@ -143,14 +149,6 @@ is.continuous <- function(x) is.numeric(x) && !is.integer(x)
 
 ## utilities for plots
 
-# get plot annotation for variables
-getLabel <- function(v) {
-  sc <- switch(getVm("scaling"), none="", classical="scaled", 
-      MCD="robustly scaled", robust="robustly scaled")
-  if(nchar(sc)) paste(v, " (", sc, ")", sep="")
-  else v
-}
-
 # print out which variables are highlighted
 highlightInfo <- function(highlight, selection = c("any","all"), imputed = FALSE) {
   if(!imputed) label <- "missings"
@@ -176,7 +174,7 @@ initializePlot <- function(xlim, ylim) {
 # locator with error catching
 locatorVIM <- function(error = FALSE) {
   pt <- try(locator(1), silent=TRUE)
-  if(class(pt) == "try-error" && !error) pt <- NULL
+  if(inherits(pt, "try-error") && !error) pt <- NULL
   pt
 }
 
